@@ -10,6 +10,7 @@ from .mongo import Mongo
 from .pdf import Pdf
 from .plotly import Plotly
 from .html import Html
+from .jupyter import Jupyter
 from .cityfalcon import Cityfalcon
 from .prediction import Prediction
 from .sentiment_analysis import SentimentAnalysis
@@ -19,14 +20,19 @@ from .airtable import Airtable
 from .zappier import Zappier
 from .ifttt import Ifttt
 import requests
+import os
 
-__version__ = "0.18.11"
+__version__ = "0.22.0"
 
 __github_repo = "jupyter-naas/drivers"
 
+if os.environ.get("NAAS_DRIVER_LIGHT_INIT"):
+    exit()
+
 darkknight = DarkKnight()
 airtable = Airtable()
 zappier = Zappier()
+jupyter = Jupyter()
 integromat = Integromat()
 ifttt = Ifttt()
 yahoo = Yahoo()
@@ -45,6 +51,12 @@ prediction = Prediction()
 sentiment_analysis = SentimentAnalysis()
 toucan = Toucan()
 
+__doc_url = "https://naas.gitbook.io/drivers/"
+
+
+def doc():
+    return __doc_url
+
 
 def version():
     print(__version__)
